#[non_exhaustive]pub struct TimeCode {
pub string: String,
pub hh: u32,
pub mm: u32,
pub ss: u32,
pub ttt: u32,
}Expand description
A TimeCode represents any valid SRT or VTT timestamps used for cue timing
such as 00:01:14.815 or 01:14.815
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.string: Stringcopy of string used to create TimeCode
hh: u32hours field from timecode
mm: u32minutes field from timecode
ss: u32seconds field from timecode
ttt: u32milliseconds field from timecode
Implementations
Sourceimpl TimeCode
impl TimeCode
Sourcepub fn to_seconds(&self) -> u32
pub fn to_seconds(&self) -> u32
Converts TimeCode to seconds
Converts hh and mm to seconds, sums them with ss field. milliseconds are skipped, rounding the number seconds down to the nearest second.
use title_parser::timecode::{TimeCodeTrait};
let tc = "00:01:14.815".to_timecode().unwrap();
assert_eq!(tc.to_seconds(), 74);Trait Implementations
impl StructuralPartialEq for TimeCode